@@ -148,7 +148,8 @@ class AzureMLLunaUtils(BaseLunaUtils):
             if not os.path.exists(targetFolder):
                 os.makedirs(targetFolder)
             childRun.download_files(prefix = 'outputs', output_directory=targetFolder, append_prefix=False)
-            return predecessorRun.get_file_names()
+            files = childRun.get_file_names()
+            return [file for file in files if file.startswith("outputs/")]
         
         return None
         
