@@ -18,4 +18,6 @@ class AzureMLLunaLogger(BaseLunaLogger):
         if os.path.isdir(local_path):
             run.upload_folder(upload_path, local_path)
         elif os.path.isfile(local_path):
-            run.upload_file(upload_path, local_path)
\ No newline at end of file
+            run.upload_file(upload_path, local_path)
+        else:
+            print("can find the specified path {}".format(local_path))
\ No newline at end of file
