@@ -165,11 +165,14 @@ def RunProject(azureml_workspace, entry_point, experiment_name, parameters, tags
     if azureml_workspace:
         run_config = RunConfiguration.load(luna_config['azureml']['run_config'])
 
-        workspace_full_path = os.path.join(luna_config['azureml']['test_workspace_path'], luna_config['azureml']['test_workspace_file_name'])
-        with open(workspace_full_path) as file:
-            documents = json.load(file)
-            aml_compute = documents['AmlCompute']
-            run_config.target = aml_compute
+        if compute_cluster == "default":
+            workspace_full_path = os.path.join(luna_config['azureml']['test_workspace_path'], luna_config['azureml']['test_workspace_file_name'])
+            with open(workspace_full_path) as file:
+                documents = json.load(file)
+                aml_compute = documents['AmlCompute']
+                run_config.target = aml_compute
+        else:
+            run_config.target = compute_cluster
 
         arguments = GetPipelineArguments(luna_config['MLproject'], entry_point, parameters)
 
